Changelog
=========

v1.0.0-a.1 (2019-05-03)
------------------------

* First alpha release on PyPI
* Not usable, no code yet. I just released it to reserve the name

v1.0.0-b.0 (2019-05-11)
------------------------

* First beta release on PyPI
* Includes the most basic set of features: Board, Lifeforms, Simulator
* Add Documentation with Sphinx and ReadTheDocs
* Add Continuous Integration using Azure Pipelines

v1.0.0-b.1 (2019-05-13)
~~~~~~~~~~~~~~~~~~~~~~~

* Update documentation with examples `PR#13 <https://github.com/ljvmiranda921/seagull/pull/17>`_
* Fix README.md `PR#15 <https://github.com/ljvmiranda921/seagull/pull/15>`_
* Ensure that board.state will never change `PR#20 <https://github.com/ljvmiranda921/seagull/pull/20>`_
